*26-01-2021*
**_ Neurophysiological Validation of Simultaneous Intrinsic and Reflexive Joint Impedance Estimates _**

# Introduction
For an optimal reading experience render this document with a Markdown parser.

This readme file describes the work presented in [1].

The work presents the neurophyiological validation of simultaneous intrinsic and reflexive joint impedance estimates. The simultaneous intrinsic and reflexive joint impedance parameters are estimated using an online parallel-cascade (PC) algorithm. The neurophyiological validation is performed by investigating the linear association of the PC algorithm estimations with EMG. The work was performed and presented within a clinical/rehabilitation context to support the use of the PC technology for people with joint hyper-resistance.

In short, the main goal of this paper is to perform a group-level neurophysiological validation of the PC system identification technique to support its clinical application. 

This document provides an overview of the documents, data and other materials and directs to other documentation that provides and explains more details.

# Contents
1. How to use
2. Contact
3. References
4. Licensing
5. Files

# How to use
This repository covers all documents related to the execution, analysis and reporting of the work published in [1].

The *Code* folder contains all scripts/functions (MATLAB and R) and the *Data* folder contains all experimental data used within the project. The experiment was executed with the Achilles Perturbator device of the University of Twente. The scripts within the *Code* folder are further supported by functions in *Code/Functions* and intermediate stored data *Code/Processed*. Additional details about the code and data can be found in a readme within each respective folder: **_!README_code.md_** and **_!README_data.md_**).

## Prerequisites
The experiment was performed on a Dell Precision 3541 laptop with an Intel Core i7-9750H processor, 32 GB RAM, running Windows 10. The data analysis and processing was performed on a Dell Precision 3510 laptop with an Intel Core i7-6700HQ processor, 16 GB RAM, running Window 10.

All MATLAB code was created, tested and run in MATLAB 2017b. All R code was created, tested and run in R3.6.2. For both MATLAB and R, the code might be forward compatible or easily adaptable to newer versions otherwise.

# Contact
For questions and suggestions, please contact either:

Edwin van Asseldonk (e.h.f.vanasseldonk@utwente.nl)
or
Ronald van 't Veld (r.c.vantveld@utwente.nl)

Department of Biomechanical Engineering  
Faculty of Engineering Technology  
University of Twente  
Enschede, The Netherlands  

# References
[1] van 't Veld RC, Schouten AC, van der Kooij H, van Asseldonk EHF. Neurophysiological Validation of Simultaneous Intrinsic and Reflexive Joint Impedance Estimates. Journal of NeuroEngineering and Rehabilitation. doi: [10.1186/s12984-021-00809-3](https://doi.org/10.1186/s12984-021-00809-3)

# Licensing
"Neurophysiological Validation of Simultaneous Intrinsic and Reflexive Joint Impedance Estimates" (c) by van 't Veld RC, Schouten AC, van der Kooij H, van Asseldonk EHF  
"Neurophysiological Validation of Simultaneous Intrinsic and Reflexive Joint Impedance Estimates" is licensed under a Creative Commons Attribution 4.0 International License.  
You should have received a copy of the license along with this work. If not, see [CC BY 4.0](http://creativecommons.org/licenses/by/4.0/).

The software within the *Code* folder is licensed under a MIT License with the exception of the 'shadedErrorBar.m'-function.  
The 'shadedErrorBar.m'-function is licensed under a LGPL-3.0 license as this work was derived from the [Matlab File Exchange](https://nl.mathworks.com/matlabcentral/fileexchange/26311-raacampbell-shadederrorbar).

# Files
- [Code]
  The *Code* folder contains the MATLAB and R scripts used during the experiment and afterwards during analysis. Moreover, the code folder includes all functions and intermediate stored data in support of the analysis scripts.
	- [Functions]
	The *Functions* folder contains all MATLAB functions in support of the analysis scripts.
		- alignSortEMGData.m
		- alignSortMechData.m
		- dZOHLpFilter.m
		- getEMGStretchEnsembles.m
		- getMechStretchEnsembles.m
		- getStretchIndices.m
		- interpolateEMGData.m
		- loadData.m
		- onlineSepStiffIdent.m
		- plotColors.m
		- plotEMGEnsemble.m
		- plotMechEnsemble.m
		- plotStiffnessIdent.m
		- postTrialOnlineSepStiffIdent.m
		- shadedErrorBar.m
		- subplotPositions.m
		- synchronizePosEMG.m
		- tls.m
		- vafSimulation.m
		- zscorenan.m
	- [Processed]
	The *Processed* folder contains data files with intermediate results, stored to enable re-use across languages (MATLAB and R) and scripts.
		- data0Nm.mat
		- data5Nm.mat
		- dataVAF.mat
		- EMGWindows.mat
		- stats0Nm.mat
		- stats5Nm.mat
	- !LICENSE_code.md
	- !LICENSE_shadedErrorBar.md
	- !README.md
	- !README_code.md
	- analyzeCorrelations.m
	- analyzeCorrelations.R
	- analyzeEnsembles.m
	- analyzeTimeseries.m
	- analyzeVAF.m
	- emgWindowAnalysis.m
	- trialAnalysis.m
- [Data]
The *Data* folder contains all experimental data from 10 participants, numbered Subject001 through Subject010.
	- [Subject001-Subject010]
		- [A01_SetZero]
			- Trial2C1R1.mat
		- [A05_CaliAchilles]
			- Trial1C1R1.mat
		- [D01_SepStiffnessIdent]
			- Trial4C1R1.mat
			- Trial4C2R1.mat
			- Trial4C3R1.mat
			- Trial4C4R1.mat
		- Subject001.mat - Subject010.mat
	- !LICENSE_data.md
	- !README.md
	- !README_data.md
	- Ludvig_UT_Validation.mat