# Introduction
The **_Code_** folder contains the MATLAB and R scripts used during analysis. Moreover, the code folder includes intermediate processed data, used directly in support of the code. The sections within this readme are in line with the subsections of the Results section in the article [1].

# Code Directory
- [Code]
	- [Functions]
	- [Processed]
		- data0Nm.mat
		- data5Nm.mat
		- dataVAF.mat
		- EMGWindows.mat
		- stats0Nm.mat
		- stats5Nm.mat
	- !LICENSE_code.md
	- !LICENSE_shadedErrorBar.md
	- !README_code.md
	- analyzeCorrelations.m
	- analyzeCorrelations.R
	- analyzeEnsembles.m
	- analyzeTimeseries.m
	- analyzeVAF.m
	- emgWindowAnalysis.m
	- trialAnalysis.m
	
# Analysis Scripts	
## Pre-Analysis
The *trialAnalysis.m* and *emgWindowAnalysis.m* scripts were both used before the actual results analysis. The *trialAnalysis.m* was used to create a feeling for the experimental data and potential data quality issues within either biomechanical or EMG data. For example, data was checked for completeness and missing samples as well as EMG artifacts (50 Hz, movement). The *emgWindowAnalysis.m* script was used to place the reflexive EMG window (M1) for each subject using ensemble averages, plotted seperately for all 4 experimental blocks, of the reflexive response (*Processed/EMGWindows.mat*), called by all other data analysis scripts.
	
## Experiment Time Series
The *analyzeTimeseries.m* script was used to analyze the timeseries data of the representative subject (=Subject006). The timeseries analysis includes a study of the raw measured signals (e.g. position, torque) and processed signals based on the outcome measures (e.g. intrinsic stiffness and background EMG activity). The results are summarized in Figure 4 of the article.

## Hold Period Ensemble Averages
The *analyzeEnsembles.m* script was used to analyze the ensemble averaged responses (i.e. reponses aligned at dorsiflexion perturbation onset), again of the representative subject (=Subject006). The ensemble average analysis was performed on the raw measured signals (only EMG was high-pass filtered and rectified) and split across each hold period performed during the experiment. Analysis of ensemble averages was supported by the system identification outcome measures (intrinsic stiffness and reflexive gain) per hold period. Figure 3A and Figure 5 of the article can be generated using the *analyzeEnsembles.m* script. Furthermore, the *analyzeVAF.m* script was used in support of the ensemble analysis to provide a measure of model fit quality (by means of 'variance accounted for', VAF) within each hold period. The *analyzeVAF.m* script computes the VAF for the ensemble averages of all subjects and hold periods (*Processed/dataVAF.mat*).

## Correlation Analysis
The *analyzeCorrelations.m* and *analyzeCorrelations.R* scripts were used to analyze the correlations between the system identification and EMG outcome measures. The MATLAB *analyzeCorrelations.m* script was used for data preparation and to generate Figure 3B/3C and Figure 6 of the article, including the total least squares computations. The R *analyzeCorrelations.R* script was used to perform the statistical parts, i.e. calculating all correlations and performing the bootstrap analysis to obtain the 95% confidence intervals on the correlations. The *data0Nm.mat*, *data5Nm.mat*, *stats0Nm.mat* and *stats5Nm.mat* in the **_Processed_** folder are all used to store the results of the *analyzeCorrelations.m* and *analyzeCorrelations.R* scripts, such that the results are available within both scripting languages (both can process the MATLAB .mat file extension).

## Supporting Functions
The MATLAB functions supporting the analysis scripts elaborated on above are included in the **_Functions_** folder. The functions content will not be elaborated on in the readme and the reader is referred to the MATLAB-style function comments/explanations included general description and definitions of syntax, inputs and outputs. Plots were exported using the export_fig function from the [Matlab File Exchange](https://nl.mathworks.com/matlabcentral/fileexchange/23629-export_fig).

# References
[1] van 't Veld RC, Schouten AC, van der Kooij H, van Asseldonk EHF. Neurophysiological Validation of Simultaneous Intrinsic and Reflexive Joint Impedance Estimates. Journal of NeuroEngineering and Rehabilitation. doi: [10.1186/s12984-021-00809-3](https://doi.org/10.1186/s12984-021-00809-3)