function [DataSysID] = postTrialOnlineSepStiffIdent(DataMech,Settings)
%postTrialOnlineSepStiffIdent Post-Trial Seperation of Intrinsic and Reflexive Stiffness
%   Online system identification method to obtain estimates of the
%   intrinsic and reflexive contributions to joint stiffness, executed
%   offline, post-trial.
%
%	SYNTAX
%   DataSysID = postTrialOnlineSepStiffIdent(DataMech,Settings)
%
%	INPUTS
%	DataMech = Selection of (bio)mechanical signals (struct)
%   Settings = Overview of all processing settings (struct)
%
%   OUTPUT
%   DataSysID = System Identification (seperate intrinsic/reflexive) results (struct)

    % Set and get online algorithm settings
    pspBias = 0; % [rad] Perturbation neutral point
    [~,~,~,States,Settings] = onlineSepStiffIdent(pspBias,Settings.pspTStep,Settings.visFiltSetting);
    % Pre-allocate size and outputs
    N = numel(DataMech.posMeas);
    kbiInt = zeros(N,3);
    gRef = zeros(N,1);
    % Iteratively loop through the entire data set with online algorithm
    idx = 1;
    for ii = 1:ceil(N/100)
        % Call online system identification function and save results
        if (ii == ceil(N/100))
            [kbi,g,~,States,~] = onlineSepStiffIdent(DataMech.posMeas(idx:N),DataMech.velMeas(idx:N),DataMech.tqMeas(idx:N),States,Settings);
            kbiInt(idx:end,:) = -kbi';
            gRef(idx:end) = -g;
        else
            [kbi,g,~,States,~] = onlineSepStiffIdent(DataMech.posMeas(idx:idx+99),DataMech.velMeas(idx:idx+99),DataMech.tqMeas(idx:idx+99),States,Settings);
            kbiInt(idx:idx+99,:) = -kbi';
            gRef(idx:idx+99) = -g;
            idx = idx+100;
        end
    end
    % Store System Identification data
    DataSysID.t = DataMech.t;
    DataSysID.intrStiffness = kbiInt(:,1);
    DataSysID.intrDamping = kbiInt(:,2);
    DataSysID.intrInertia = kbiInt(:,3);
    DataSysID.reflexive = gRef;
end