function [B] = tls(x,y)
%TLS Total-Least Squares Solver
%   Computed the total-least squares solution in the total least squares 
%   sense to the under- or overdetermined system of equations x*B = y. TLS
%   solver is used for error-in-variable problems, i.e. noise on both
%   measured inputs (x) and outputs (y).
%
%	SYNTAX
%   [B] = tls(x,y)
%
%	INPUTS
%   x = Input matrix (MxN double)
%   y = Output matrix (Mx1 double)
%
%   OUTPUTS
%	B = Estimated parameter vector (Lx1 double)
%
%   Source: https://en.wikipedia.org/wiki/Total_least_squares

    [~,n]   = size(x);            % n is the width of X (X is m by n)
    Z       = [x y];              % Z is X augmented with Y.
    [~,~,V] = svd(Z,0);           % find the SVD of Z.
    Vxy     = V(1:n,1+n:end);     % Take the block of V consisting of the first n rows and the n+1 to last column
    Vyy     = V(1+n:end,1+n:end); % Take the bottom-right block of V.
    B       = -Vxy/Vyy;
end