#Load all relevant libraries and empty workspace
library(R.matlab)
library(boot)
rm(list = ls())

#Pre-allocate the intrinsic and reflexive outputs
numMuscles <- 4 #1 = SOL, 2 = TA, 3 = GM, 4 = GL
intrStore <- array(,dim=c(numMuscles,4))
reflStore <- array(,dim=c(numMuscles,4))
# Read data from Matlab and set muscle index
data <- readMat('Processed/data0Nm.mat') #Uncomment either 0 or 5
#data <- readMat('Processed/data5Nm.mat') #  "  "         "    "
# Set random seed for replication
set.seed(1)

# FUNCTIONS
corrWithinBoot <- function(subject,sysID,emg){
  # Reshape vectors
  sysID <- matrix(sysID,ncol=nlevels(subject))
  emg   <- matrix(emg,ncol=nlevels(subject))
  # Store NaN from EMG in SysID/VAF
  sysID[is.nan(emg)] <- NaN
  # Subject Z-score
  sysIDZ <- apply(sysID,2,scale)
  emgZ   <- apply(emg,2,scale)
  # Vectorize and remove NaN
  sysIDZ <- sysIDZ[!is.nan(emg)]
  emgZ   <- emgZ[!is.nan(emg)]
  
  # Perform correlation
  SIvEMGCor <- cor(cbind(sysIDZ,emgZ))
  # Compute CIs via bootstrap
  cor.boot <- function(data,k) cor(data[k,])[1,2]
  cor.SIvEMG <- boot(data=cbind(sysIDZ,emgZ),statistic=cor.boot,R=1999)
  ciCor <- boot.ci(cor.SIvEMG, conf = 0.95, type="bca")

  corrStore <- cbind(length(sysIDZ),SIvEMGCor[1,2],t(ciCor$bca[4:5]))
}

# Get all data linked to a specific subject, store as factor
subject <- as.factor(rep(seq(1,10), each=10))
for (ii in 1:numMuscles){
  # Store data for each subject (both system identification and EMG)
  # Intrinsic
  intrStore[ii,] <- corrWithinBoot(subject,data$dataIntr[,ncol(data$dataIntr)],data$dataIntr[,ii])
  # Reflexive
  reflStore[ii,] <- corrWithinBoot(subject,data$dataRefl[,ncol(data$dataRefl)],data$dataRefl[,ii])
}

# Export the results to .mat file
#writeMat('Processed/stats0Nm.mat',intrStore=intrStore,reflStore=reflStore)