%% Clean Start
clc, clearvars, close all;

%% Settings
% Overview of conditions to-be processed
Settings.isEMG = 1; % Flag to process EMG (if true)
Settings.isPostTrialIdent = 0; % Flag to process online system identification post-trial (if true)
Settings.isPlot = 1; % Flag to process plots: 0 = none, 1 = data-specific, 2 = all
% Define data storage location
dataCD = cd; fileSepIdxs = strfind(dataCD,filesep);
dataCD = dataCD(1:fileSepIdxs(end)-1);
dataSet = [dataCD '/Data/Subject006/D01_SepStiffnessIdent/Trial4C1R1'];
% Data column/row order settings
Settings.mechDataColumns = [1 6 7 2 3 4 2]; % [-] Columns used to load data [time, posRef, velRef, posMeas, velMeas, tqMeas, Sync]
Settings.EMGDataRows = [1 2 3 4 5 6]; % [-] Rows used to load data [SOL, TA, GM, GL, Sync, Sawtooth]

% Perturbation
Settings.pertAmpl = 0.035; % [rad] Amplitude (peak-to-peak)
% Filter settings
Settings.fcLpPos = 200;  % [Hz] Low-pass filter position for visualization
Settings.nHpEMG  = 2;    % [-]  High-pass filter order for EMG
Settings.fcHpEMG = 5;    % [Hz] High-pass filter frequency for EMG
% Length of (bio)mechanical data segments
Settings.tSegStart = 0.3; % [s] Time before zero/onset
Settings.tSegEnd   = 0.4; % [s] Time after zero/onset
% Length of EMG data segments
Settings.tSegStartEMG = 0.04; % [s] Time before zero/onset
Settings.tSegEndEMG   = 0.2;  % [s] Time after zero/onset
% Create cell array of all perturbation characteristics to be sorted for
Settings.sortFields = {'rise','fall','pulse','step','stepFall','postPulse','postStep'};
% Add folder with all shared functions
addpath(genpath('Functions'));

%% Load data
% Load (bio)mechanical and [optionally] EMG data
[DataMech,DataEMG,DataSysID,Settings] = loadData(dataSet,Settings);

%% Post-trial online system identification
if (Settings.isPostTrialIdent)
    % Post-trial online seperation of intrinsic and reflexive stiffness
    DataPTSysID = postTrialOnlineSepStiffIdent(DataMech,Settings);
else
    DataPTSysID = struct(); % Empty struct, if no processing is desired
end

%% Synchronize EMG
if (Settings.isEMG)
    % Synchronize EMG and motor data based on position sync.
    [DataEMG.t,DataEMG.syncEMGScaled] = synchronizePosEMG(DataMech.sync,DataEMG.sync,DataMech.t,DataMech.dt,DataEMG.dt);
end

%% Time domain aligning & sorting
% Align and sort the (bio)mechanical data
MechEns = alignSortMechData(DataMech,Settings);

if (Settings.isEMG)
    % Align and sort the EMG data
    EMGEns = alignSortEMGData(DataMech,DataEMG,MechEns.StretchIdxs,Settings);
end

%% Figures
if (Settings.isPlot)
    % (Bio)mechanical time domain
    plotMechEnsemble(DataMech,MechEns,Settings);
    
    % EMG time domain
    if (Settings.isEMG)
        plotEMGEnsemble(DataMech,DataEMG,EMGEns,Settings);
    end
    
    % System identification results
    plotStiffnessIdent(DataSysID,DataPTSysID,Settings);
end